.TH PSSEGY l "6 July 1999"
.SH NAME
pssegy \- Create imagemasked postscript from SEGY file
.SH SYNOPSIS
\fBpssegy\fP \fISEGYfile\fP \fB\-J\fP\fIparameters\fP \fB\-R\fP\fIwest/east/south/north\fP \fB\-F\fP[\fBrgb|gray\fP]|-W 
[ \fB\-I\fP] [ \fB\-N\fP ] [ \fB\-B\fP\fIbias\fP ] [ \fB\-C\fP\fIclip\fP ] 
[ \fB\-Z\fP ] [ \fB\-X\fP\fIscale\fP ] [ \fB\-Y\fP\fIsample int\fP ]
[ \fB\-S\fP\fIheader\fP ] [ \fB\-L\fP\fInsamp\fP ] 
[ \fB\-M\fP\fIntrace\fP ] [ \fB\-U\fP\fIredvel\fP ] [ \fB-T\fP\fIfilename\fP ]
[ \fB-E\fP\fIerror\fP ]
[ \fB\-O\fP ] [ \fB\-K\fP ] [ \fB\-P\fP ][ \fB\-V \fP ] 
.SH DESCRIPTION
\fBpssegy\fP reads a native (IEEE) format SEGY file and produces a
\fIPostScript\fP image of the seismic data. The \fIimagemask\fP
operator is used so that the seismic data are plotted as a 1-bit
deep bitmap in a single
(user-specified) color or gray shade, with a transparent background.
The bitmap resolution is taken from the current GMT defaults.
The seismic traces may be plotted at their true locations using information
in the trace headers (in which case order of the
traces in the file is not significant).
 Standard GMT geometry routines are used so that
in principle any map projection may be used, however it is likely that the
geographic projections will lead to unexpected results. Beware also
that some parameters have non-standard meanings.

Note that the order of operations before the seismic data are plotted is
deviation*[clip]([bias]+[normalize](sample value)). Deviation determines
how far \fIin the plot coordinates\fP a [normalized][biased][clipped] sample
value of 1 plots from the trace location.

The SEGY file should be a disk image of the tape format (ie 3200 byte
text header, which is ignored, 400 byte binary reel header, and
240 byte header for each trace) with samples as native real*4 (IEEE real
on all the platforms to which I have access)
.TP
\fISEGYfile\fP
Seismic data set to be imaged
.TP
.B \-J
Selects the map projection. Scale is inch/degree, 1:xxxxx, or width in inch (upper case modifier).
.br
.sp
\fBNON-GEOGRAPHICAL PROJECTIONS:\fP
.br
.sp
\fB\-Jp\fP\fIscale\fP (Linear projection for polar (theta,r) coordinates)
.br
\fB\-Jx\fP\fIx-scale\fP[\fBl|p\fP\fIpow\fP][\fI/y-scale\fP[\fBl|p\fP\fIpow\fP]] (Linear, log, and power scaling)
.br
More details can be found in the \fBpsbasemap\fP manpages. For seismic
plots where time or depth increases downward, use a negative y-scale
.br
.TP
.B \-R
\fIwest, east, south,\fP and \fInorth\fP specify the Region of interest.  To specify boundaries
in degrees and minutes [and seconds], use the dd:mm[:ss] format.  Append \fBr\fP if lower left and upper right
map coordinates are given instead of wesn.
.br
.TP
.B \-F[\fIrgb\fP|\fIgray\fP]
Fill trace (variable area, defaults to filling positive). rgb or gray gives
the color with which the imagemask is filled.
.TP
.B \-W
Draw wiggle trace.
.TP
\fI Must specify at least one of -W and -F.\fP
.SH OPTIONS
No space between the option flag and the associated arguments.
.TP
.B \-I
Fill negative rather than positive excursions.
.TP
.B \-N
Normalize trace by dividing by rms amplitude over full trace length.
.TP
.B \-B
Bias to apply to data (added to sample values).
.TP
.B \-C
Sample value at which to clip data (clipping is applied to both positive and
negative values).
.TP
.B \-Z
Don't plot traces with zero rms amplitude.
.TP
.B \-X
Multiply trace locations by scale before plotting.
.TP
.B \-Y
Override sample interval in reel header.
.TP
.B \-S
Read trace locations from trace headers: header is either c for CDP,
o for offset, or b<num> to read a long starting at byte <num> in the
header (first byte corresponds to num=0). Default has location given by
trace number.
.TP
.B \-L
Override number of samples per trace in reel header (program attempts to
determine number of samples from each trace header if possible to
allow for variable length traces).
.TP
.B \-M
Override number of traces specified in reel header. Program detects
end of file (relatively) gracefully, but this parameter limits number
of traces that the program attempts to read.
.TP
.B \-U
Apply reduction velocity by shifting traces \fIupwards\fP by redvel/|offset|.
Negative velocity removes existing reduction. Units should be consistent with
offset in trace header and sample interval.
.TP
.B \-T
Plot only traces whose location corresponds to a list given in \fIfilename\fP.
Order in which traces are listed is not significant - the entire space is
checked for each trace.
.TP
.B \-E
Allow \fIerror\fP difference between requested and actual trace locations
when using -T option.
.TP
.B \-K
More \fIPostScript\fP code will be appended later [Default terminates the plot system].
.TP
.B \-O
Selects Overlay plot mode [Default initializes a new plot system].
.TP
.B \-P
Selects Portrait plotting mode [\fBGMT\fP Default is Landscape, see gmtdefaults to change this].
.TP
.B \-V
Selects verbose mode, which will send progress reports to stderr [Default runs "silently"].

.SH EXAMPLES
To plot the SEGY file wa1.segy with normalized traces plotted at true offset 
locations, clipped at +-3 and with wiggle trace and positive variable area
shading in black, try
.br
.sp
pssegy wa1.segy \fB\-JX\fP5/\-5 \fB\-R\fP0/100/0/10 \fB\-C\fP3 \fB\-N\fP \fB\-S\fPo \fB\-W\fP \fB\-F\fP0 > segy.ps
.br
.sp
To plot the SEGY file wa1.segy with traces plotted at true cdp*0.1, clipped
at +-3, with bias -1 and negative variable area shaded red, try
.br
.sp
pssegy wa1.segy \fB\-JX\fP5/\-5 \fB\-R\fP0/100/0/10 \fB\-C\fP3 \fB\-S\fPc \fB\-X\fP0.1 \fB\-F\fP255/0/0 \fB\-B\fP\-1 \fB\-I\fP > segy.ps

.SH "SEE ALSO"
.IR gmt (l),
.IR pssegyz (l)
